from distutils.core import setup

setup(
    name          = 'leon_nester',
    version       = '1.2.0',
    py_modules    = ['nester'],
    author        = 'Leon',
    author_email  = 'wangliang0210@gmail.com',
    url           = 'http://www.headfirstlabs.com',
    description   = 'A Nester',
    )
